[![Build Status](https://travis-ci.org/sannykr/allsortalgo.svg?branch=master)](https://travis-ci.org/sannykr/allsortalgo)

Sorting Algorithms
========================

This project includes implementations of the following sorting algorithms:

1. Bubble sort: In bubble sort, we repeatedly swap the adjancent elements if they are in wrong order. It's time complexity is O(N*N)

2. Insertion sort: In insertion sort, we start with a sub-list of size 2, and insert the right-most elements to the proper location 
   in such a way that the list remains sorted. It's time complexity is O(N*N)

3. merge sort: In merge sort, we use divide and conquer strategy and sort the sublists and merge them recursively. It's time complexity
   is O(N*logN)

I will be adding more sorting algorithms to this project.    

---------------
